import os.path
import sys
import tempfile
import urllib.request
import xlrd
import zipfile

from argparse import ArgumentParser

from qakit.practitest import practitest
from qakit.practitest.report_subunit_results_to_practitest import _read_config 


def steps_for_test(sheet, test_name):
    # Find the test steps in the sheet
    steps = ''
    step_number = 1
    for row in range(1, sheet.nrows):
        row_values = sheet.row(row)
        if row_values[1].value == test_name:
            steps += ' {}.'.format(step_number)
            step_number += 1
            if row_values[3].value:
                for line in row_values[3].value.split('\n'):
                    if not line:
                        line = '.'
                    steps += ' ' + line + '\n'
            if row_values[4].value:
                for line in row_values[4].value.split('\n'):
                    if not line:
                        line = '.'
                    steps += '  ' + line + '\n'
    return steps

def main():
    parser = ArgumentParser(
        'Create a Checkbox provider from a Practitest testset'
    )
    parser.add_argument('testset', help='The ID of the testset to use.')
    parser.add_argument(
        '--whitelist',
        action='store_true',
        help='Generate whitelist instead' # REMOVE
    )
    args = parser.parse_args()
    # These are the instances that haven't been run
    pt = practitest.PractitestSession(
        **_read_config(os.path.join(os.path.dirname(__name__), 'config.ini'))
    )
    instances = pt.get_instances(args.testset)
    notrun = [instance for instance in instances if instance['run_status']['value'] not in ('PASSED','FAILED')]
    # This does the test step export
    export = pt.get_export(410)
    url = export.json()['url']
    tempdir = tempfile.mkdtemp()
    r = urllib.request.urlretrieve(url, os.path.join(tempdir, 'steps.zip'))
    # Now we extract the spreadsheet from the zip
    stepszip = open(r[0], 'rb')
    z = zipfile.ZipFile(stepszip)
    xlsx = ''
    for name in z.namelist():
        if name.endswith('.xlsx'):
            z.extract(name, tempdir)
            xlsx = os.path.join(tempdir, name)
    # Now we open the spreadsheet and get the tests sheet
    sheet = xlrd.open_workbook(xlsx).sheets()[0]
    # First we create the provider file
    with open(os.path.join(tempdir, 'practitest.provider'), 'w') as provider:
        provider.write("""[PlainBox Provider]
description = The Practitest provider
location = {}
name = 2015.com.canonical:qa-practitest
version = 1.0""".format(tempdir))
    # Now we create the jobs and whitelist
    if not os.path.exists(os.path.join(tempdir, 'jobs')):
        os.makedirs(os.path.join(tempdir, 'jobs'))
    if not os.path.exists(os.path.join(tempdir, 'whitelists')):
        os.makedirs(os.path.join(tempdir, 'whitelists'))
    jobs = open(os.path.join(tempdir, 'jobs', 'practitest.txt'), 'w')
    whitelist = open(
        os.path.join(tempdir, 'whitelists', 'practitest.whitelist'), 'w'
    )
    for test in notrun:
        test_name = ''.join(
            [c for c in test['name'] if c.isalnum() or c is ' ']
        )
        cb_id = 'practitest/{}/{}'.format(
            '-'.join([word.lower() for word in test_name.split()]),
            test['id']
        )
        whitelist.write(cb_id + '\n')
        jobs.write('plugin: manual\n')
        jobs.write('id: {}\n'.format(cb_id))
        jobs.write('summary: {}\n'.format(test['name']))
        jobs.write('description:\n')
        jobs.write(steps_for_test(sheet, test['name']))
        jobs.write('\n')
    jobs.close()
    whitelist.close()
    print(tempdir)

if __name__ == "__main__":
    sys.exit(main())
