
# PractiSanity
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import unittest
from unittest import mock

import practisanity
import sanity_suite
from tests.test_practitest import TESTS, INSTANCES


class GetInstanceSanitySuiteNameTestCase(unittest.TestCase):

    def test_get_instance_sanity_suite_name(self):
        instance = {
            'name': ('Complete wizard successfully '
                     '(English, SIM inserted, Wi-Fi connected)'),
            'run_status': {'name': 'Run Status', 'value': 'PASSED'},
            'last_run': {'name': 'Last Run', 'value': '27-Feb-2015  00:44'},
            'system_id': 1188312,
            'id': '24:1'
        }
        sanity_name = 'ubuntu_sanity_tests.tests.test_settings_wizard.SettingsWizardTestCase.test_complete_settings_wizard'  # NOQA
        result = practisanity._get_instance_sanity_suite_name(
            TESTS, instance)
        self.assertEqual(sanity_name, result)


class BuildPractisanityTestMapTestCase(unittest.TestCase):

    def test_build_practisanity_test_map(self):
        test_name = 'ubuntu_sanity_tests.tests.test_bluetooth.BluetoothTestCase.test_disconnected_list_populates'  # NOQA
        practitest_instance =  {
            'system_id': 1188331,
            'id': '24:11',
            'last_run': {'value': '04-Mar-2015  17:12', 'name': 'Last Run'},
            'run_status': {'value': 'FAILED', 'name': 'Run Status'},
            'name': 'Discover Bluetooth devices'
        }
        practitest_tests = TESTS
        sanity_suite_results = sanity_suite.parse_subunit_results(
            os.path.join(os.path.dirname(__file__),
                         'test-results.subunit'))
        result = practisanity._build_practisanity_test_map(
            practitest_instance,
            practitest_tests,
            sanity_suite_results)
        self.assertEqual(
            test_name,
            result['test_name'])
        self.assertEqual(
            'Discover Bluetooth devices',
            result['practitest_instance']['name'])
        self.assertEqual(
            test_name,
            result['sanity_test_result']['id'])


class ConfirmNameOfTestset(unittest.TestCase):

    @mock.patch('practitest._get_testset')
    @mock.patch('practisanity.input', create=True)
    def test_confirm_name_of_testset(self, mock_input, mock_get_testset):
        mock_input.return_value = "Y"
        self.assertTrue(practisanity._confirm_name_of_testset(24))

    @mock.patch('practitest._get_testset')
    @mock.patch('practisanity.input', create=True)
    def test_confirm_name_of_testset_false(self,
                                           mock_input,
                                           mock_get_testset):
        mock_input.return_value = "n"
        self.assertFalse(practisanity._confirm_name_of_testset(24))

    @mock.patch('practitest._get_testset')
    @mock.patch('practisanity.input', create=True)
    def test_confirm_name_of_testset_gibberish(self,
                                               mock_input,
                                               mock_get_testset):
        mock_input.return_value = "GIBBERISH"
        self.assertTrue(practisanity._confirm_name_of_testset(24))
