# qakit - tools for UEQA engineers
# Copyright (C) 2014-2015 Canonical
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.


from functools import partial
from testtools import TestCase

from qakit import silo

DEFAULT = object()


def make_passed_completed_card(date=None, assigned_to=u'', name=u''):
    return silo.CompletedCard('Passed', date, assigned_to, name)


def make_failed_completed_card(date=None, assigned_to=u'', name=u''):
    return silo.CompletedCard('Failed', date, assigned_to, name)



class OpenCardFilterTests(TestCase):

    def test_no_backlog(self):
        actual = silo._get_open_cards(lambda: [silo.Card()])
        self.assertEqual(list(actual), [])

    def test_single_backlog(self):
        in_backlog = silo.Card("Some Name", "Need QA Sign-off")
        expected = [in_backlog]
        actual = silo._get_open_cards(lambda: [in_backlog])
        self.assertEqual(list(actual), expected)

    def test_mixed(self):
        in_backlog = silo.Card("Some Name", "Need QA Sign-off")
        in_progress = silo.Card("Some Name", "Under Testing")
        in_passed = silo.Card("Some Name", "Passed")
        in_failed = silo.Card("Some Name", "Failed")
        all_cards = [in_backlog, in_progress, in_passed, in_failed]
        expected = [in_backlog]
        actual = silo._get_open_cards(lambda: all_cards)
        self.assertEqual(list(actual), expected)


def test_suite():
    from unittest import TestLoader
    return TestLoader().loadTestsFromName(__name__)
